#
# spec file for package chezmoi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chezmoi
Version:        2.40.4
Release:        1.1
Summary:        A multi-host manager for dotfiles
License:        MIT
Group:          Development/Tools/Version Control
URL:            https://chezmoi.io
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Recommends:     git
BuildRequires:  golang(API) >= 1.18

%description
chezmoi is a manager for personal preference configs and state files
("dotfiles") that programs such as editors might create. chezmoi
sources dotfiles from a GitHub repository and installs them onto new,
empty machines.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a 1

%build
go build \
        -mod=vendor \
        -buildmode=pie \
        -tags noupgrade \
        -ldflags "-X main.version=%version
                  -X main.builtBy=build.opensuse.org"

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
install -D -m 0644 "completions/%{name}-completion.bash" "%{buildroot}/%{_datadir}/bash-completion/completions/%{name}"
install -D -m 0644 "completions/%{name}.fish" "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"
install -D -m 0644 "completions/%{name}.zsh" "%{buildroot}/%{_datadir}/zsh/site-functions/_%{name}"

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Mon Oct 30 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.4:
  * fix: Make stdinIsATTY return false if --no-tty is passed
* Fri Oct 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.3:
  * feat: Add env config var as an alternative to scriptEnv
  * feat: Warn when overriding CHEZMOI_ env vars
  * feat: Set CHEZMOI_ and scriptEnv env vars for all invoked commands
* Wed Oct 11 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.2:
  * upstream version bump
- Update to version 2.40.1:
  * feat: Add Path Separator and Path List Separator to provided template values.
  * feat: Ignore AppleDouble files in externals
  * feat: find[One]Executable in user-supplied paths
  * fix: Only invoke diff pager if command modifies filesystem
  * fix: Don't use replace-executable for WinGet installations
  * fix: Add chattr +remove support for files
* Tue Sep 19 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.40.0:
  * feat: Implement the path-style flag for status
  * feat: Add plugin support
  * feat: Allow overlapping, non-conflicting externals
  * feat: Add decryption of non-armored files to age command
  * fix: Use diff pager for all diff output if configured
  * fix: provide a consistent error for cd to file
* Wed Sep  6 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.39.1:
  * fix: Ensure default template data when reading .chezmoidata in subdir
* Tue Sep  5 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.39.0:
  * feat: add .chezmoi.targetFile template variable
  * feat: Add age command
  * feat: Add bitwardenSecrets template function
  * fix: Handle .chezmoidata files in subdirectories when template has already been executed
* Mon Aug 28 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.38.0:
  * feat: Add gitHubReleases and gitHubTags
  * chore: Reformat long lines
  * feat: Add promptChoice and promptChoiceOnce template functions
  * fix: Fix minor issues with promptBool docs and errors
  * feat: Restore --autotemplate flag to add command
  * fix: Fix race condition in concurrent parsing of externals
  * chore: Update dependencies
* Mon Aug  7 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.37.0:
  * feat: Read personal mackup config files
  * feat: Add support for Doppler
  * feat: Extend re-add command to accept an optional list of targets
  * fix: Avoid concurrent map access when evaluating multiple templates
  * feat: Add isExecutable template function
  * chore: Fix isExecutable tests on Windows
  * chore: Update dependencies
* Tue Aug  1 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.36.1:
  * fix: Make detection of mackup config dir more robust
  * fix: Ensure that templates cannot modify each other's data
  * chore: Move core packages back to internal
* Tue Aug  1 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.36.0:
  * feat: Add .chezmoiexternals directory for multiple externals
  * fix: Respect setting diff.pager to the empty string as disabling the pager
  * feat: Add undocumented mackup command
  * chore: Update dependencies
* Mon Jul 17 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.35.0:
  * feat: Add archive-file externals
  * fix: Never consider localhost.localdomain in /etc/hosts as the FQDN
  * feat: Add support for HCP Vault Secrets
  * chore: Miscellaneous fixes
* Tue Jul  4 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.3:
  * fix: Check .chezmoiignore before protected paths
  * fix: Parse hostnames from all loopback addresses in /etc/hosts
  * fix: Respect persistentState config variable
  * chore: Miscellaneous fixes
  * chore: Update dependencies
* Mon Jun 19 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.2:
  * chore: Simplify code by using strings.EqualFold, time.Before
  * chore: Use http.NoBody instead of nil
  * fix: Handle multiple files in .chezmoidata directory
  * chore: Update dependencies
* Mon Jun 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.1:
  * feat: Add git.commitMessageTemplate configuration variable
* Mon Jun  5 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.34.0:
  * feat: Add support for .chezmoidata directory
  * fix: Fix init --debug flag
  * fix: Fix parsing of flags to secret keyring delete command
  * chore: Update dependencies
* Tue May 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.6:
  * fix: Only create empty files if they have the empty_ attribute
  * chore: Refactor internal handling of remove_ directories
  * chore(editorconfig): Remove quotes from editorconfig file
  * fix: Set CHEZMOI_SOURCE_DIR env var in init when using .chezmoiroot
  * chore: Update dependencies
* Fri May 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.5:
  * fix: Fix commands for managed files in exact_ directories
  * fix: Ensure the sourceDir is updated before creating config file
  * chore: Update dependencies
* Tue May  2 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.4:
  * fix: Fix init --promptBool for promptBoolOnce template function
  * fix: Respect executable file modes in external_ directories
  * fix: Fix chezmoi rm with files in exact_ directories
  * chore: Update dependencies
* Wed Apr 26 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.3:
  * fix: Correct capitalization of .chezmoi.config template variables
* Fri Apr 21 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.2:
  * fix: Set CHEZMOI_ environment variables for modify_ scripts
  * fix: Don't download ignored git-repo externals
  * feat: Add .chezmoi.config template variable
  * chore: Update dependencies
* Wed Apr 12 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.1:
  * chore: Add rbw version check to doctor command
  * fix: Allow source dir to be a git worktree
  * chore: Update dependencies
* Fri Mar 24 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.33.0:
  * fix: Don't list entries in git-repo externals as unmanaged
  * chore: Minor fixes
  * feat: Add support for ejson
  * chore: Tidy up ejson default key dir
  * feat: Add jq template function
  * chore: Deprecate --autotemplate
  * feat: Set $CHEZMOI_VERBOSE based on --verbose
  * fix: Only set $CHEZMOI_VERBOSE when --verbose is set
  * Update dependencies
* Mon Mar 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.32.0:
  * fix: Allow underscores and dots in GitHub dotfile repo name guesses
  * Improve chezmoi cd command
  * feat: Add support for the JSONC format
  * feat: Refuse to add chezmoi files to chezmoi
  * feat: Add pre- and post-command hooks
  * chore: Miscellaneous password manager cleanups
  * feat: Add rbw template function for Bitwarden
  * chore: Update dependencies
* Thu Mar  2 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.31.1:
  * feat: Add Dashlane password manager support
  * feat: Add Dashlane secure notes support
  * chore: Update dependencies
* Fri Feb 17 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.31.0:
  * feat: Print a warning when chezmoi add is called with an ignored entry
  * feat: Cache GitHub API results by default to stay under rate limit
  * feat: Display progress bars by default when stdout is a TTY
  * feat(bitwarden): Grab attachment by object name
  * fix: Eliminate [DEFAULT] section for fromIni map
  * feat: Add --with-stdin flag to execute-template command
  * chore: Update dependencies
* Mon Feb 13 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.30.1:
  * Add deleteValueAtPath and pruneEmptyDicts template functions
  * feat: Extend toPrettyJson template function to take indent
  * fix: Fix chezmoi target-path when using .chezmoiroot
  * chore: Use strings.Cut{Prefix,Suffix}
* Tue Feb  7 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.30.0:
  * feat: Add zstd compression support
  * feat: Add external_ attribute for directories
  * fix: Make chezmoi init --purge-binary always remove binary
  * Set CHEZMOI* environment variables when running cd command
  * chore: Update dependencies
* Wed Jan 25 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.4:
  * fix: Revert buggy diff library
* Tue Jan 24 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.3:
  * feat: Add --recursive flag to chattr command
  * feat: Check config file format in doctor command
  * fix: Support .zip files with empty internal directories
  * fix: Only prompt once for KeePassXC password
  * fix: Remove problematic username guessing in init command
* Mon Jan 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Remove `changesgenerate` service
  Upstream provides a better changelog than the one this service is able to
  generate from git commits.
* Mon Jan 16 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.2:
  * feat: Add keepassxc.prompt config variable
  * chore: Update dependencies
* Mon Jan  9 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.29.1:
  * fix: Fix init --ssh
  * feat: Add hexDecode and hexEncode template functions
  * fix: Fix bug where edit --watch only applied the first change
  * fix: Don't request authentication when cloning public repo with builtin git
  * fix: Improve error message when state database cannot be locked
  * chore: Improve error message when persistent state cannot be opened
  * feat: Allow cd command to take the destination directory as an argument
  * feat: Add --path-style=source-{absolute,relative} option to managed command
  * feat: Allow .chezmoi{external,ignore,remove} files to have a .tmpl suffix
  * chore: Update dependencies
* Thu Dec 22 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.28.0:
  * feat: Add lstat template function
  * feat: Add --path-style option to managed and unmanaged commands
  * feat: Add verification of external checksums
  * chore: Update dependencies
* Mon Dec  5 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.3:
  * fix: Respect config file umask setting when creating entries
  * fix: Don't attempt to run empty scripts
  * chore: Update dependencies
  * docs: Update stat.md to reference os.Stat
* Fri Nov 25 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.2:
  * fix: Respect diff filter in removes with external diff tool
  * fix: Allow underscores in SourceHut usernames
  * feat: Add update.command and update.args config variables
  * feat: Add an optional path argument to the cd command
  * chore: Check that not both of --force and --interactive flags are set
  * fix: Make re-add command respect --interactive flag
  * chore: Update dependencies
* Mon Nov 14 2022 filippo.bonazzi@suse.com
- Update to version 2.27.1:
  * chore: Make generation of versioninfo.json work without tags or git repo
  * feat: Remember HTTP username in URL in init command
  * fix: Don't show always scripts in apply --verbose when excluded from diffs
* Wed Nov  9 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.27.0:
    feat: Suppress newlines from onepasswordRead
    feat: Allow modify_ scripts to be executed as templates
    chore: Blacklist buggy version of github.com/bmatcuk/doublestar/v4
    feat: Add line ending template directive
    feat: Add setValueAtPath template function
    fix: Don't merge non-files in merge-all command
    feat: Add --script-contents flag to diff command
    chore: Better handle errors when globbing
    feat: Add cat-config and dump-config commands
    chore: Remove unused field
    chore: Refactor handling of annotations
    feat: Allow prompt*Once template functions to take paths
    fix: Fix exclusion of externals
    chore: Update dependencies
    feat: Add completion template function
* Wed Nov  2 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 2.26.0:
    feat: Improve handling of include and exclude for externals and encrypted files
    feat: Extend --include and --exclude flags to include templates
    feat: Add --recurse-submodules flag to init and update command
    chore: Fix refactored --include and --exclude flags
    feat: Add per-template configurable delimiters
    chore: Tweak template directive implementation
    feat: Add option to exclude scripts that are always run
    fix: Extend template directives functionality
    chore: Fix comments that start from an incorrect name
    chore: Use fs.ModePerm instead of 0o777 for all permissions
    fix: Include git repo external state in state dump output
    chore: Improve error messages from git-repo externals
    fix: Construct templateDataMap manually
    chore: Reorder eqFold template function reference page
    chore: Update dependencies
* Fri Oct 21 2022 Jan Engelhardt <jengelh@inai.de>
- Put up new package description following
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Thu Oct 20 2022 filippo.bonazzi@suse.com
- Update to version 2.25.0
    fix: Use textconv in interactive diffs
    feat: Add shell completion for --include and --exclude flags
    feat: Add eqFold template function
    feat: Add scriptEnv configuration variable
    feat: Use target paths in automatically generated commit messages
    feat: 1Password account lookup table
    chore: Fail if multiple config file templates or config files are found
    fix: Make chattr {no,}encrypted decrypt and encrypt source file
* Fri Sep 30 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Clean up spec file
* Thu Sep 29 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Initial version 2.24.0
